@@ -1,7 +1,9 @@
 __author__ = "Wren J. R. (uberfastman)"
-__email__ = "wrenjr@yahoo.com"
+__email__ = "uberfastman@uberfastman.dev"
 
 from yfpy.data import Data
+from yfpy.exceptions import YahooFantasySportsException, YahooFantasySportsDataNotFound
+from yfpy.logger import get_logger
 from yfpy.models import User, Game, League, Team, Standings, Manager, RosterAdds, TeamLogo, TeamPoints, \
     TeamStandings, OutcomeTotals, Streak, Settings, RosterPosition, StatCategories, StatModifiers, Stat, \
     StatPositionType, Bonus, Matchup, MatchupGrade, Player, ByeWeeks, Headshot, Name, PlayerPoints, PlayerStats, \
